@@ -2274,6 +2274,9 @@ print.virtual <- function(x, ...){
 }
 
 
+# not exported - just here to avoid cross calling the dll from ff
+R_bit_as_hi <- function(x, range, offset)
+.Call("R_bit_as_hi", x, range, offset, PACKAGE="bit")
 
 
 
